@@ -38,6 +38,7 @@
 #include <lal/LALInferenceTemplate.h>
 #include <lal/LALInferenceProposal.h>
 #include <lal/LALInferenceInit.h>
+#include <lal/LALInferenceCalibrationErrors.h>
 
 LALInferenceRunState *initialize(ProcessParamsTable *commandLine);
 void initializeNS(LALInferenceRunState *runState);
@@ -48,14 +49,12 @@ void LogNSSampleAsMCMCSampleToFile(LALInferenceRunState *state, LALInferenceVari
 
 void LogNSSampleAsMCMCSampleToArray(LALInferenceRunState *state, LALInferenceVariables *vars)
 {
-  NSFillMCMCVariables(vars,state->priorArgs);
   LALInferenceLogSampleToArray(state, vars);
   return;
 }
 
 void LogNSSampleAsMCMCSampleToFile(LALInferenceRunState *state, LALInferenceVariables *vars)
 {
-  NSFillMCMCVariables(vars,state->priorArgs);
   LALInferenceLogSampleToFile(state, vars);
   return;
 }
@@ -67,7 +66,6 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
 	char help[]="\
 Initialisation arguments:\n\
 (--verbose [N])\tOutput more info. N=1: errors, N=2 (default): warnings, N=3: info \n\
-(--randomseed seed           Random seed for Nested Sampling)\
 (--resume)\tAllow non-condor checkpointing every 4 hours. If give will check for OUTFILE_resume and continue if possible\n\n";
 	LALInferenceRunState *irs=NULL;
 	ProcessParamsTable *ppt=NULL;
@@ -87,7 +85,7 @@ Initialisation arguments:\n\
 	INT4 x=0;
 	ppt=LALInferenceGetProcParamVal(commandLine,"--verbose");
 	if(ppt) {
-	  if(ppt->value){
+	  if(ppt->value[0]){
 	    x=atoi(ppt->value);
 	    switch(x){
 	     case 0:
@@ -211,27 +209,30 @@ Nested sampling arguments:\n\
  --Nlive N\tNumber of live points to use\n\
 (--Nmcmc M)\tOver-ride auto chain length determination and use this number of MCMC samples.\n\
 (--maxmcmc M)\tUse at most this number of MCMC points when autodetermining the chain (5000).\n\
+(--Nmcmcinitial M)\tUse this number of MCMC points when initially resampling from the prior (otherwise default is to use maxmcmc).\n\
 (--sloppyratio S)\tNumber of sub-samples of the prior for every sample from the limited prior\n\
 (--Nruns R)\tNumber of parallel samples from logt to use(1)\n\
 (--tolerance dZ)\tTolerance of nested sampling algorithm (0.1)\n\
 (--randomseed seed)\tRandom seed of sampling distribution\n\
 (--prior )\t Set the prior to use (InspiralNormalised,SkyLoc,malmquist) default: InspiralNormalised\n\n\
 (--sampleprior N)\t For Testing: Draw N samples from the prior, will not perform the nested sampling integral\n\
-  ---------------------------------------------------------------------------------------------------\n\
-  --- Noise Model -----------------------------------------------------------------------------------\n\
-  ---------------------------------------------------------------------------------------------------\n\
-  (--psdFit)                       Run with PSD fitting\n\
-  (--psdNblock)                    Number of noise parameters per IFO channel (8)\n\
-  (--psdFlatPrior)                 Use flat prior on psd parameters (Gaussian)\n\
-  (--removeLines)                  Do include persistent PSD lines in fourier-domain integration\n\
-  (--KSlines)                      Run with the KS test line removal\n\
-  (--KSlinesWidth)                 Width of the lines removed by the KS test (deltaF)\n\
-  (--chisquaredlines)              Run with the Chi squared test line removal\n\
-  (--chisquaredlinesWidth)         Width of the lines removed by the Chi squared test (deltaF)\n\
-  (--powerlawlines)                Run with the power law line removal\n\
-  (--powerlawlinesWidth)           Width of the lines removed by the power law test (deltaF)\n\
-  (--xcorrbands)                   Run PSD fitting with correlated frequency bands\n\
-  \n";
+---------------------------------------------------------------------------------------------------\n\
+--- Noise Model -----------------------------------------------------------------------------------\n\
+---------------------------------------------------------------------------------------------------\n\
+(--glitchFit)                    Run with glitch fitting\n\
+(--glitchNmax)                   Max number of glitches to fit\n\
+(--psdFit)                       Run with PSD fitting\n\
+(--psdNblock)                    Number of noise parameters per IFO channel (8)\n\
+(--psdFlatPrior)                 Use flat prior on psd parameters (Gaussian)\n\
+(--removeLines)                  Do include persistent PSD lines in fourier-domain integration\n\
+(--KSlines)                      Run with the KS test line removal\n\
+(--KSlinesWidth)                 Width of the lines removed by the KS test (deltaF)\n\
+(--chisquaredlines)              Run with the Chi squared test line removal\n\
+(--chisquaredlinesWidth)         Width of the lines removed by the Chi squared test (deltaF)\n\
+(--powerlawlines)                Run with the power law line removal\n\
+(--powerlawlinesWidth)           Width of the lines removed by the power law test (deltaF)\n\
+(--xcorrbands)                   Run PSD fitting with correlated frequency bands\n\
+\n";
 //(--tdlike)\tUse time domain likelihood.\n";
 
 	ProcessParamsTable *ppt=NULL;
@@ -261,14 +262,14 @@ Nested sampling arguments:\n\
 	/* Default likelihood is the frequency domain one */
 	runState->likelihood=&LALInferenceUndecomposedFreqDomainLogLikelihood;
 
-    /* Check whether to use the SkyLocalization prior. Otherwise uses the default LALInferenceInspiralPriorNormalised. That should probably be replaced with a swhich over the possible priors. */
+    /* Check whether to use the SkyLocalization prior. Otherwise uses the default LALInferenceInspiralPrior. That should probably be replaced with a swhich over the possible priors. */
     ppt=LALInferenceGetProcParamVal(commandLine,"--prior");
     if(ppt){
       if(!strcmp(ppt->value,"SkyLoc")) runState->prior = &LALInferenceInspiralSkyLocPrior;
       if(!strcmp(ppt->value,"malmquist")) initializeMalmquistPrior(runState);
     }
     else{
-      runState->prior = &LALInferenceInspiralPriorNormalised;
+      runState->prior = &LALInferenceInspiralPrior;
     }
     /* For Compatibility with MCMC command line */
     if(LALInferenceGetProcParamVal(commandLine,"--malmquist-prior")) initializeMalmquistPrior(runState);
@@ -375,7 +376,11 @@ Arguments for each section follow:\n\n";
 
 	/* Read command line and parse */
 	procParams=LALInferenceParseCommandLine(argc,argv);
-	
+  if(LALInferenceGetProcParamVal(procParams,"--help"))
+  {
+    fprintf(stdout,"%s",help);
+  }
+
 	/* initialise runstate based on command line */
 	/* This includes reading in the data */
 	/* And performing any injections specified */
@@ -390,29 +395,32 @@ Arguments for each section follow:\n\n";
 	LALInferenceInitModelFunction initModelFunc=NULL;
 	if(LALInferenceGetProcParamVal(procParams,"--correlatedGaussianLikelihood"))
 		initModelFunc=&LALInferenceInitModelReviewEvidence;
-        else if(LALInferenceGetProcParamVal(procParams,"--bimodalGaussianLikelihood"))
-                initModelFunc=&LALInferenceInitModelReviewEvidence_bimod;
-        else if(LALInferenceGetProcParamVal(procParams,"--rosenbrockLikelihood"))
-                initModelFunc=&LALInferenceInitModelReviewEvidence_banana;
+  else if(LALInferenceGetProcParamVal(procParams,"--bimodalGaussianLikelihood"))
+    initModelFunc=&LALInferenceInitModelReviewEvidence_bimod;
+  else if(LALInferenceGetProcParamVal(procParams,"--rosenbrockLikelihood"))
+    initModelFunc=&LALInferenceInitModelReviewEvidence_banana;
 	else
 		initModelFunc=&LALInferenceInitCBCModel;
 	state->initModel=initModelFunc;
 	state->model = initModelFunc(state);
-    state->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
-    memset(state->currentParams, 0, sizeof(LALInferenceVariables));
-    LALInferenceCopyVariables(state->model->params, state->currentParams);
-    state->templt = state->model->templt;
-
-        /* Choose the likelihood */
-        LALInferenceInitLikelihood(state);
-    
-       /* Print command line arguments if help requested */
-        if(LALInferenceGetProcParamVal(state->commandLine,"--help"))
-        {
-                fprintf(stdout,"%s",help);
-		exit(0);
-        }
+  if (state->model){
+  state->currentParams = XLALMalloc(sizeof(LALInferenceVariables));
+  memset(state->currentParams, 0, sizeof(LALInferenceVariables));
+  LALInferenceCopyVariables(state->model->params, state->currentParams);
+  state->templt = state->model->templt;
+  }
+  /* Choose the likelihood */
+  LALInferenceInitLikelihood(state);
 
+  /* Apply calibration errors if desired*/
+  LALInferenceApplyCalibrationErrors(state,procParams);
+  
+  /* Exit since we printed all command line arguments */
+  if(LALInferenceGetProcParamVal(state->commandLine,"--help"))
+  {
+    exit(0);
+  }
+  
 	/* Call setupLivePointsArray() to populate live points structures */
 	LALInferenceSetupLivePointsArray(state);
 
